Documentation
¶
Index ¶
- func NewBackupInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewBackupStorageLocationInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewDeleteBackupRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewDownloadRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredBackupInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredBackupStorageLocationInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredDeleteBackupRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredDownloadRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredPodVolumeBackupInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredPodVolumeRestoreInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredResticRepositoryInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredRestoreInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredScheduleInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredServerStatusRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredVolumeSnapshotLocationInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewPodVolumeBackupInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewPodVolumeRestoreInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewResticRepositoryInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewRestoreInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewScheduleInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewServerStatusRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewVolumeSnapshotLocationInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type BackupInformer
- type BackupStorageLocationInformer
- type DeleteBackupRequestInformer
- type DownloadRequestInformer
- type Interface
- type PodVolumeBackupInformer
- type PodVolumeRestoreInformer
- type ResticRepositoryInformer
- type RestoreInformer
- type ScheduleInformer
- type ServerStatusRequestInformer
- type VolumeSnapshotLocationInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewBackupInformer ¶
func NewBackupInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewBackupInformer constructs a new informer for Backup type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewBackupStorageLocationInformer ¶
func NewBackupStorageLocationInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewBackupStorageLocationInformer constructs a new informer for BackupStorageLocation type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewDeleteBackupRequestInformer ¶
func NewDeleteBackupRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewDeleteBackupRequestInformer constructs a new informer for DeleteBackupRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewDownloadRequestInformer ¶
func NewDownloadRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewDownloadRequestInformer constructs a new informer for DownloadRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredBackupInformer ¶
func NewFilteredBackupInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredBackupInformer constructs a new informer for Backup type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredBackupStorageLocationInformer ¶
func NewFilteredBackupStorageLocationInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredBackupStorageLocationInformer constructs a new informer for BackupStorageLocation type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredDeleteBackupRequestInformer ¶
func NewFilteredDeleteBackupRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredDeleteBackupRequestInformer constructs a new informer for DeleteBackupRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredDownloadRequestInformer ¶
func NewFilteredDownloadRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredDownloadRequestInformer constructs a new informer for DownloadRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredPodVolumeBackupInformer ¶
func NewFilteredPodVolumeBackupInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredPodVolumeBackupInformer constructs a new informer for PodVolumeBackup type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredPodVolumeRestoreInformer ¶
func NewFilteredPodVolumeRestoreInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredPodVolumeRestoreInformer constructs a new informer for PodVolumeRestore type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredResticRepositoryInformer ¶
func NewFilteredResticRepositoryInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredResticRepositoryInformer constructs a new informer for ResticRepository type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredRestoreInformer ¶
func NewFilteredRestoreInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredRestoreInformer constructs a new informer for Restore type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredScheduleInformer ¶
func NewFilteredScheduleInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredScheduleInformer constructs a new informer for Schedule type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredServerStatusRequestInformer ¶
func NewFilteredServerStatusRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredServerStatusRequestInformer constructs a new informer for ServerStatusRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredVolumeSnapshotLocationInformer ¶
func NewFilteredVolumeSnapshotLocationInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredVolumeSnapshotLocationInformer constructs a new informer for VolumeSnapshotLocation type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewPodVolumeBackupInformer ¶
func NewPodVolumeBackupInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewPodVolumeBackupInformer constructs a new informer for PodVolumeBackup type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewPodVolumeRestoreInformer ¶
func NewPodVolumeRestoreInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewPodVolumeRestoreInformer constructs a new informer for PodVolumeRestore type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewResticRepositoryInformer ¶
func NewResticRepositoryInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewResticRepositoryInformer constructs a new informer for ResticRepository type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewRestoreInformer ¶
func NewRestoreInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewRestoreInformer constructs a new informer for Restore type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewScheduleInformer ¶
func NewScheduleInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewScheduleInformer constructs a new informer for Schedule type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewServerStatusRequestInformer ¶
func NewServerStatusRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewServerStatusRequestInformer constructs a new informer for ServerStatusRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewVolumeSnapshotLocationInformer ¶
func NewVolumeSnapshotLocationInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewVolumeSnapshotLocationInformer constructs a new informer for VolumeSnapshotLocation type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type BackupInformer ¶
type BackupInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.BackupLister
}
BackupInformer provides access to a shared informer and lister for Backups.
type BackupStorageLocationInformer ¶
type BackupStorageLocationInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.BackupStorageLocationLister
}
BackupStorageLocationInformer provides access to a shared informer and lister for BackupStorageLocations.
type DeleteBackupRequestInformer ¶
type DeleteBackupRequestInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.DeleteBackupRequestLister
}
DeleteBackupRequestInformer provides access to a shared informer and lister for DeleteBackupRequests.
type DownloadRequestInformer ¶
type DownloadRequestInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.DownloadRequestLister
}
DownloadRequestInformer provides access to a shared informer and lister for DownloadRequests.
type Interface ¶
type Interface interface {
// Backups returns a BackupInformer.
Backups() BackupInformer
// BackupStorageLocations returns a BackupStorageLocationInformer.
BackupStorageLocations() BackupStorageLocationInformer
// DeleteBackupRequests returns a DeleteBackupRequestInformer.
DeleteBackupRequests() DeleteBackupRequestInformer
// DownloadRequests returns a DownloadRequestInformer.
DownloadRequests() DownloadRequestInformer
// PodVolumeBackups returns a PodVolumeBackupInformer.
PodVolumeBackups() PodVolumeBackupInformer
// PodVolumeRestores returns a PodVolumeRestoreInformer.
PodVolumeRestores() PodVolumeRestoreInformer
// ResticRepositories returns a ResticRepositoryInformer.
ResticRepositories() ResticRepositoryInformer
// Restores returns a RestoreInformer.
Restores() RestoreInformer
// Schedules returns a ScheduleInformer.
Schedules() ScheduleInformer
// ServerStatusRequests returns a ServerStatusRequestInformer.
ServerStatusRequests() ServerStatusRequestInformer
// VolumeSnapshotLocations returns a VolumeSnapshotLocationInformer.
VolumeSnapshotLocations() VolumeSnapshotLocationInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type PodVolumeBackupInformer ¶
type PodVolumeBackupInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.PodVolumeBackupLister
}
PodVolumeBackupInformer provides access to a shared informer and lister for PodVolumeBackups.
type PodVolumeRestoreInformer ¶
type PodVolumeRestoreInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.PodVolumeRestoreLister
}
PodVolumeRestoreInformer provides access to a shared informer and lister for PodVolumeRestores.
type ResticRepositoryInformer ¶
type ResticRepositoryInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.ResticRepositoryLister
}
ResticRepositoryInformer provides access to a shared informer and lister for ResticRepositories.
type RestoreInformer ¶
type RestoreInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.RestoreLister
}
RestoreInformer provides access to a shared informer and lister for Restores.
type ScheduleInformer ¶
type ScheduleInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.ScheduleLister
}
ScheduleInformer provides access to a shared informer and lister for Schedules.
type ServerStatusRequestInformer ¶
type ServerStatusRequestInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.ServerStatusRequestLister
}
ServerStatusRequestInformer provides access to a shared informer and lister for ServerStatusRequests.
type VolumeSnapshotLocationInformer ¶
type VolumeSnapshotLocationInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.VolumeSnapshotLocationLister
}
VolumeSnapshotLocationInformer provides access to a shared informer and lister for VolumeSnapshotLocations.